#!/bin/bash

# ============LICENSE_START=======================================================
#  Copyright (C) 2019 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================

set -o nounset
set -o errexit
set -o pipefail

if [[ "$DELETE_STACK" != "true" || "$HW_TYPE" != "cloud" ]]; then
  echo "Info  : Skipping stack delete as it is either not a cloud deployment or slack deletion is disabled!"
  exit 0
fi

# NOTE (fdegir): offline installer removes /opt/engine so we prepare venv ourselves for openstack cli
if [[ "$EXECUTION_MODE" == "offline-deployment" ]]; then
  sudo /bin/rm -rf /opt/engine/.venv
  virtualenv --python python3 --never-download /opt/engine/.venv
  /bin/cp -f /opt/engine/offline/pip/pip.conf /opt/engine/.venv/
  set +u
  source /opt/engine/.venv/bin/activate
  set -u
  pip install --quiet --upgrade pip
  pip install --quiet -r /opt/engine/offline/git/engine/requirements.txt
  deactivate
fi

set +u
source /opt/engine/.venv/bin/activate
set -u

echo "Info: Deleting stack $HEAT_STACK_NAME and keypair $KEYPAIR_NAME"
echo "-------------------------------------------------------------------------"
source /tmp/openrc && /bin/rm -f /tmp/openrc
openstack stack delete $HEAT_STACK_NAME --wait --yes
openstack keypair delete $KEYPAIR_NAME
echo "-------------------------------------------------------------------------"
echo "Info: Stack $HEAT_STACK_NAME and keypair $KEYPAIR_NAME have been deleted!"

# vim: set ts=2 sw=2 expandtab:
